@@ -11,7 +11,7 @@
 
 
 static NSInteger const kMaxLaunchTimeInSeconds = 15;
-static NSString * const kVersion = @"1.8.0";
+static NSString * const kVersion = @"1.9.0";
 static NSString * const kJsPrintSource = @"(function() { return document.getElementsByTagName('html')[0].outerHTML })();";
 
 
@@ -117,7 +117,7 @@ static NSString * const kJsPrintSource = @"(function() { return document.getElem
     }
 }
 
-- (void)listTabsLinks:(Arguments *)args {
+- (void)listTabLinks:(Arguments *)args {
     if (self->outputFormat == kOutputFormatJSON) {
         NSMutableArray *tabInfos = [[NSMutableArray alloc] init];
 
@@ -151,6 +151,37 @@ static NSString * const kJsPrintSource = @"(function() { return document.getElem
     }
 }
 
+- (void)listTabsWithLink:(Arguments *)args {
+    if (self->outputFormat == kOutputFormatJSON) {
+        NSMutableArray *tabInfos = [[NSMutableArray alloc] init];
+        for(chromeWindow *window in self.chrome.windows) {
+            for (chromeTab *tab in window.tabs) {
+                NSDictionary *tabInfo = @{
+                    @"windowId": @(window.id),
+                    @"windowName": window.name,
+                    @"id": @(tab.id),
+                    @"title": tab.title,
+                    @"url": tab.URL,
+                };
+                [tabInfos addObject:tabInfo];
+            }
+        }
+        NSDictionary *output = @{
+            @"tabs": tabInfos,
+        };
+        [self printJSON:output];
+    } else {
+        for (chromeWindow *window in self.chrome.windows) {
+            for (chromeTab *tab in window.tabs) {
+                if (self.chrome.windows.count > 1) {
+                    printf("[%ld:%ld] title: %s, url: %s\n", (long)window.id, (long)tab.id, tab.title.UTF8String, tab.URL.UTF8String);
+                } else {
+                    printf("[%ld] title: %s, url: %s\n", (long)tab.id, tab.title.UTF8String, tab.URL.UTF8String);
+                }
+            }
+        }
+    }
+}
 
 - (void)listTabsInWindow:(Arguments *)args {
     NSInteger windowId = [args asInteger:@"id"];
